export default inspect;
export type Options = {
    /**
     * Specify levels to expand arrays and objects.
     */
    depth?: number;
    /**
     * Length to truncate strings.
     */
    stringLength?: number;
    /**
     * Length to slice arrays, Map and Set.
     */
    collectionLength?: number;
    /**
     * Length to truncate object keys.
     */
    objectLength?: number;
};
/**
 * @typedef {object} Options
 * @property {number} [depth=2] Specify levels to expand arrays and objects.
 * @property {number} [stringLength=Number.POSITIVE_INFINITY] Length to truncate strings.
 * @property {number} [collectionLength=Number.POSITIVE_INFINITY] Length to slice arrays, Map and Set.
 * @property {number} [objectLength=Number.POSITIVE_INFINITY] Length to truncate object keys.
 */
/**
 * Inspect a value.
 * @param {*} value
 * @param {Options} [options]
 * @returns {string} A string representation of a value or an object.
 */
declare function inspect(value: any, options?: Options): string;
